"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const registry_1 = require("../../utils/registry");
const mixedContent_1 = require("./mixedContent");
/**
 * Handles _bundle_ types. A component bundle has all its source files, including the
 * root metadata xml, contained in its own directory.
 *
 * __Example Types__:
 *
 * LightningComponentBundle, AuraDefinitionBundle, CustomObject
 *
 * __Example Structure__:
 * ```text
 * foos/
 * ├── myFoo/
 * |   ├── myFoo.js
 * |   ├── myFooStyle.css
 * |   ├── myFoo.html
 * |   ├── myFoo.js-meta.xml
 *```
 */
class Bundle extends mixedContent_1.MixedContent {
    getMetadataXmlPath(pathToSource) {
        // Bundles are MixedContent, but the -meta.xml is located in the component's folder.
        const bundleRootPath = this.getPathToContent(pathToSource);
        return registry_1.findMetadataXml(bundleRootPath, path_1.basename(bundleRootPath));
    }
}
exports.Bundle = Bundle;
//# sourceMappingURL=bundle.js.map