import { BaseSourceAdapter } from './base';
import { SourcePath, MetadataType } from '../../types';
/**
 * Handles types with mixed content. Mixed content means there are one or more source
 * file(s) associated with a component with any file extension. Even an entire folder
 * can be considered "the content".
 *
 * __Example Types__:
 *
 * StaticResources, Documents, Bundle Types
 *
 * __Example Structures__:
 *
 *```text
 * foos/
 * ├── myFoo/
 * |   ├── fooFolder/
 * |      ├── foofighters.x
 * |   ├── foo.y
 * |   ├── fooBar.z
 * ├── myFoo.ext-meta.xml
 * bars/
 * ├── myBar.xyz
 * ├── myBar.ext2-meta.xml
 *```
 */
export declare class MixedContent extends BaseSourceAdapter {
    protected getMetadataXmlPath(pathToSource: SourcePath): SourcePath;
    protected getSourcePaths(fsPath: SourcePath, isMetaXml: boolean): SourcePath[];
    protected getPathToContent(source: SourcePath): SourcePath;
    /**
     * A utility for finding a component's root metadata xml from a path to a component's
     * content. "Content" can either be a single file or an entire directory. If the content
     * is a directory, the path can be files or other directories inside of it.
     * @param source
     */
    static findXmlFromContentPath(contentPath: SourcePath, type: MetadataType): SourcePath;
}
