/**
 * File system path to a source file of a metadata component.
 */
export declare type SourcePath = string;
export declare type MetadataType = {
    name: string;
    /**
     * Name of the directory where components are located in a package
     */
    directoryName: string;
    /**
     * Whether or not components are stored in folders.
     *
     * __Examples:__ Reports, Dashboards, Documents, EmailTemplates
     */
    inFolder: boolean;
    /**
     * File suffix
     *
     * Some types may not have one, such as those made up of varying file extensions.
     *
     * __Examples:__ LightningComponentBundles, Documents, StaticResources
     */
    suffix?: string;
    /**
     * Names of the subtypes if the type has any.
     */
    childXmlNames?: string[];
};
/**
 * Source information about a single metadata component.
 */
export declare type MetadataComponent = {
    fullName: string;
    type: MetadataType;
    /**
     * Path to the root metadata xml file.
     */
    xml: SourcePath;
    /**
     * Paths to additional source files, if any.
     */
    sources: SourcePath[];
};
