/// <reference types="node" />
import { SourcePath, MetadataComponent } from './common';
export declare type WriteInfo = {
    relativeDestination: SourcePath;
    source: NodeJS.ReadableStream;
};
export declare type WriterFormat = {
    component: MetadataComponent;
    writeInfos: WriteInfo[];
};
/**
 * Transforms metadata component files into different SFDX file formats
 */
export interface MetadataTransformer {
    toMetadataFormat(): WriterFormat;
    toSourceFormat(): WriterFormat;
}
/**
 * The file format for a set of metadata components.
 *
 * `metadata` - Structure for use with the metadata api.
 *
 * `source` - Friendly for local editing and comitting files to source control.
 */
export declare type SfdxFileFormat = 'metadata' | 'source';
declare type PackageName = {
    /**
     * Optional name to give to the package output, otherwise one is generated.
     */
    packageName?: string;
};
declare type DirectoryOutputOptions = PackageName & {
    /**
     * Directory path to output the converted package to.
     */
    outputDirectory: SourcePath;
};
export declare type OutputOptions = {
    directory: DirectoryOutputOptions;
};
export {};
